@@ -21,11 +21,11 @@
 # SOFTWARE.
 
 
-from . import api
-from . import scraper
-from . import utils
-from . import exceptions
+from .api import *
+from .utils import *
+from .scraper import *
+from .exceptions import *
 
 
-__version__ = "0.3.2"
+__version__ = "0.3.4"
 __author__ = "God Empress Verin"
